@@ -183,4 +183,14 @@ async def test_lock(client: objects.ObjectClient):
     await a
     await b
     assert time.time() - start > 2
-    assert len(output) == 2
\ No newline at end of file
+    assert len(output) == 2
+
+
+async def test_publisher(client: objects.ObjectClient):
+    publisher = client.publisher('abc')
+    await publisher.send("abc123")
+    await publisher.send(json={'humidity': 0.5, 'message': 'cats'}, channel='abc_details')
+    assert await publisher.listeners() == 0
+
+    with pytest.raises(RuntimeError):
+        await publisher.send()
